@@ -263,7 +263,15 @@ class SwiftlyAPIClient:
         )
 
         try:
-            df = pd.read_csv(io.StringIO(resp), dtype={"vehicleIds": str})
+            df = pd.read_csv(io.StringIO(resp), dtype={
+                "blockId": str,
+                "routeId": str,
+                "routeShortName": str,
+                "tripId": str,
+                "directionId": str,
+                "tripPatternId": str,
+                "vehicleIds": str,
+            })
         except pd.errors.EmptyDataError:
             df = pd.DataFrame()
         return df
@@ -304,7 +312,19 @@ class SwiftlyAPIClient:
         )
 
         try:
-            df = pd.read_csv(io.StringIO(resp))
+            df = pd.read_csv(
+                io.StringIO(resp),
+                dtype={
+                    "trip_id": str,
+                    "route_id": str,
+                    "block_id": str,
+                    "service_id": str,
+                    "trip_short_name": str,
+                    "route_short_name": str,
+                    "vehicle_ids": str,
+                    "driver_ids": str,
+                },
+            )
         except pd.errors.EmptyDataError:
             df = pd.DataFrame()
         return df
