@@ -1175,3 +1175,68 @@ def test_get_vehicles():
     vehicle_ids = [vehicle["externalId"] for vehicle in vehicles]
 
     assert vehicle_ids == ["0096", "0101"]
+
+@httpretty.activate
+def test_get_missing_service_export_numeric_trip_ids():
+    """
+    Test that all-numeric trip IDs are preserved as strings,
+    preventing type mismatch issues in downstream processing.
+    """
+    agency = "test_agency"
+    target_date = date(2025, 8, 5)
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    url = client._format_url(client.MISSING_SERVICE)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        url,
+        responses=[
+            httpretty.Response(
+                body="""\
+service_date,trip_completion_status,trip_adjustments,trip_id,route_id,block_id,service_id,trip_short_name,route_short_name,vehicle_ids,driver_ids,direction_id,day_of_week,num_scheduled_stops,num_observed_stops
+2025-08-05,MISSING,,1080,1,801,WD,,,,,0,3,25,0
+2025-08-05,MISSING,,11080,1,802,WD,,,,,1,3,30,0
+2025-08-05,PARTIAL,,13080,2,803,WD,Route 2,,123,,0,3,20,1
+2025-08-05,PARTIAL,,138080,2,804,WD,,,456,789,1,3,15,2
+                """,
+                status=200,
+            ),
+        ],
+    )
+
+    df = client.get_missing_service_export(target_date)
+
+    expected_df = pd.DataFrame(
+        {
+            "service_date": ["2025-08-05", "2025-08-05", "2025-08-05", "2025-08-05"],
+            "trip_completion_status": ["MISSING", "MISSING", "PARTIAL", "PARTIAL"],
+            "trip_id": ["1080", "11080", "13080", "138080"],
+            "route_id": ["1", "1", "2", "2"],
+            "block_id": ["801", "802", "803", "804"],
+            "service_id": ["WD", "WD", "WD", "WD"],
+            "vehicle_ids": [math.nan, math.nan, "123", "456"],
+            "driver_ids": [math.nan, math.nan, math.nan, "789"],
+            "direction_id": [0, 1, 0, 1],
+            "day_of_week": [3, 3, 3, 3],
+        }
+    )
+
+    # Compare selected columns to verify dtypes are correct
+    assert df[
+        [
+            "service_date",
+            "trip_completion_status",
+            "trip_id",
+            "route_id",
+            "block_id",
+            "service_id",
+            "vehicle_ids",
+            "driver_ids",
+            "direction_id",
+            "day_of_week",
+        ]
+    ].equals(expected_df)
+
+    sent_req = httpretty.last_request()
+    assert sent_req.querystring["startDate"] == ["08-05-2025"]
